==> hoteldruid-mod-de_2.3.0-1.zip: de/visualizza_contratto.php <==
<?php

switch ($messaggio) {

case "via":                                                      $messaggio = "Stra&szlig;e"; break;
case "Torna indietro":                                           $messaggio = "zur&uuml;ck"; break;
case "Da":                                                       $messaggio = "von"; break;
case "A":                                                        $messaggio = "an"; break;
case "Oggetto":                                                  $messaggio = "Betreff"; break;
case "Allega":                                                   $messaggio = "Anhang"; break;
case "Spedisci":                                                 $messaggio = "Senden"; break;
case "L'email a":                                                $messaggio = "Email an"; break;
case "è stata inviata":                                          $messaggio = "wurde gesendet an"; break;
case "bcc a":                                                    $messaggio = "bcc an"; break;
case "Non si è potuto inviare l'email a":                        $messaggio = "E-Mailversand war nicht erfolgreich an"; break;
case "documento":                                                $messaggio = "Dokument"; break;
case "<span class=\"colblu\">salvato</span> come":               $messaggio = "<span class=\"colblu\">gesichert</span> als"; break;
case "Cancella il documento":                                    $messaggio = "l&ouml;sche dies Dokument"; break;
case "Cancella i documenti":                                     $messaggio = "l&ouml;sche diese Dokumente"; break;
case "Il documento":                                             $messaggio = "Das Dokument"; break;
case "è stato <b style=\"font-weight: normal; color: blue;\">cancellato</b>":        $messaggio = "wurde <b style=\"font-weight: normal; color: blue;\">gel&ouml;scht</b>"; break;
case "Transazione <font color=\"red\">scaduta</font>":           $messaggio = "<font color=\"red\">Expired</font> Transaktion"; break;
case "Sovrascrivi":                                              $messaggio = "&Uuml;berschreiben"; break;
case "Documenti già esistenti riguardanti questa prenotazione":  $messaggio = "Es sind schon Dokumente f&uuml;r diese Buchung vorhanden"; break;
case "Documenti già esistenti riguardanti queste prenotazioni":  $messaggio = "Es sind schon Dokumente f&uuml;r diese Buchung vorhanden"; break;
case "Salva dei nuovi documenti":                                $messaggio = "Speichere neue Dokumente"; break;
case "Salva un nuovo documento":                                 $messaggio = "Speichere neues Dokument"; break;
case "<span class=\"colblu\">Attenzione</span>: una email con lo stesso oggetto è già stata inviata al cliente":        $messaggio = "<span class=\"colblu\">Warnung</span>: eine E-Mail mit dem gleichen Betreff an diese Gast wurde bereits versandt"; break;
case "Errore":                                                   $messaggio = "Fehler"; break;
case "ha scritto":  			$messaggio = "wrote"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)



?>

==> hoteldruid-mod-de_3.0.8-1.zip: de/visualizza_contratto.php <==
<?php

switch ($messaggio) {

case "via":                                                      $messaggio = "Stra&szlig;e"; break;
case "Torna indietro":                                           $messaggio = "zur&uuml;ck"; break;
case "Da":                                                       $messaggio = "von"; break;
case "A":                                                        $messaggio = "an"; break;
case "Oggetto":                                                  $messaggio = "Betreff"; break;
case "Allega":                                                   $messaggio = "Anhang"; break;
case "Spedisci":                                                 $messaggio = "Senden"; break;
case "L'email a":                                                $messaggio = "Email an"; break;
case "è stata inviata":                                          $messaggio = "wurde gesendet an"; break;
case "bcc a":                                                    $messaggio = "bcc an"; break;
case "Non si è potuto inviare l'email a":                        $messaggio = "E-Mailversand war nicht erfolgreich an"; break;
case "documento":                                                $messaggio = "Dokument"; break;
case "<span class=\"colblu\">salvato</span> come":               $messaggio = "<span class=\"colblu\">gesichert</span> als"; break;
case "Cancella il documento":                                    $messaggio = "l&ouml;sche dies Dokument"; break;
case "Cancella i documenti":                                     $messaggio = "l&ouml;sche diese Dokumente"; break;
case "Il documento":                                             $messaggio = "Das Dokument"; break;
case "è stato <b style=\"font-weight: normal; color: blue;\">cancellato</b>":        $messaggio = "wurde <b style=\"font-weight: normal; color: blue;\">gel&ouml;scht</b>"; break;
case "Transazione <font color=\"red\">scaduta</font>":           $messaggio = "<font color=\"red\">Expired</font> Transaktion"; break;
case "Sovrascrivi":                                              $messaggio = "&Uuml;berschreiben"; break;
case "Documenti già esistenti riguardanti questa prenotazione":  $messaggio = "Es sind schon Dokumente f&uuml;r diese Buchung vorhanden"; break;
case "Documenti già esistenti riguardanti queste prenotazioni":  $messaggio = "Es sind schon Dokumente f&uuml;r diese Buchung vorhanden"; break;
case "Salva dei nuovi documenti":                                $messaggio = "Speichere neue Dokumente"; break;
case "Salva un nuovo documento":                                 $messaggio = "Speichere neues Dokument"; break;
case "<span class=\"colblu\">Attenzione</span>: una email con lo stesso oggetto è già stata inviata al cliente":        $messaggio = "<span class=\"colblu\">Warnung</span>: eine E-Mail mit dem gleichen Betreff an diese Gast wurde bereits versandt"; break;
case "Errore":                                                   $messaggio = "Fehler"; break;
case "in data":  			$messaggio = "on"; break;
case "ha scritto":  			$messaggio = "wrote"; break;
case "Non si è potuto mascherare il mittente dell'email perchè attualmente <b class=\"colwarn\">SPF non è configurato correttamente</b> sul dominio della email":	$messaggio = "It was not possible to masquerade the sender of the email because currently <b class=\"colwarn\">SPF is not configured correctly</b> on the domain of email"; break;
case "L'utente amministratore può cambiare questa inpostazione in":	$messaggio = "The administrator user can change this setting in"; break;
case "configura e personalizza":  	$messaggio = "configure and customize"; break;
case "È stato raggiunto il numero massimo di email giornaliere":	$messaggio = "You have reached the maximum number of daily emails"; break;
case "Per mandare altre email l'utente amministratore può impostare un server remoto in":	$messaggio = "To comtinue sending emails the administrator user can set a remote server in"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)



?>
